@@ -1,11 +1,12 @@
 """ Apex Legends API Python Module """
 from .al_api import ApexLegendsAPI
-from .al_base import ALPlatform, ALAction
+from .al_base import ALPlatform, ALAction, ALHTTPExceptionFromResponse
 from .al_domain import ALPlayer
 
 __all__ = [
     'ApexLegendsAPI',
     'ALPlatform',
     'ALAction',
-    'ALPlayer'
+    'ALPlayer',
+    'ALHTTPExceptionFromResponse'
 ]
